@@ -38,20 +38,25 @@ def _parse_args(args_arr):
         default=[0, 'kft'],
         help="altitude and lenght unit, default='0 kft'")
     parser.add_argument(
-        '--Mach', dest='M', metavar='', nargs=None, type=float,
+        '-M', '--mach-number', dest='M', metavar='', nargs=None, type=float,
         default=None, help="Mach number")
     parser.add_argument(
-        '--TAS', dest='TAS', metavar='', nargs=2, type=str, default=None,
+        '-T', '--TAS', dest='TAS', metavar='', nargs=2, type=str, default=None,
         help="true airspeed and speed unit, e.g. '150 knots'")
     parser.add_argument(
-        '--CAS', dest='CAS', metavar='', nargs=2, type=str, default=None,
+        '-C', '--CAS', dest='CAS', metavar='', nargs=2, type=str, default=None,
         help="calibrated airspeed and speed unit, e.g. '150 knots'")
     parser.add_argument(
-        '--EAS', dest='EAS', metavar='', nargs=2, type=str, default=None,
+        '-E', '--EAS', dest='EAS', metavar='', nargs=2, type=str, default=None,
         help="equivalent airspeed and speed unit, e.g. '150 knots'")
     parser.add_argument(
-        '--ell', dest='ell', metavar='', nargs=2, type=str, default=None,
+        '-L', '--length-scale', dest='length_scale', metavar='', nargs=2,
+        type=str, default=None,
         help="length scale, e.g. '10 ft'")
+    parser.add_argument(
+        '--no-pretty-print', dest='no_pretty_print', default=False,
+        action='store_true',
+        help="turn off pretty print (throws error in some terminals)")
 
     args = parser.parse_args(args_arr)
 
@@ -80,9 +85,10 @@ def main():
     TAS_ = None if args.TAS is None else _dimension(args.TAS)
     CAS_ = None if args.CAS is None else _dimension(args.CAS)
     EAS_ = None if args.EAS is None else _dimension(args.EAS)
-    ell_ = None if args.ell is None else _dimension(args.ell)
-    fc = FlightCondition(h=h_, M=M_, TAS=TAS_, CAS=CAS_, EAS=EAS_, ell=ell_)
-    print(fc.tostring(full_output=True, pretty_print=False))
+    L_ = None if args.length_scale is None else _dimension(args.length_scale)
+    fc = FlightCondition(h=h_, M=M_, TAS=TAS_, CAS=CAS_, EAS=EAS_, L=L_)
+    print(fc.tostring(full_output=True,
+                      pretty_print=(not args.no_pretty_print)))
 
 
 if __name__ == '__main__':
